@@ -4,9 +4,11 @@
 :license: Apache License, Version 2.0, see LICENSE file
 :copyright: (c) 2020 GitBib
 """
-from .pyasstosrt import Substation
+from .pyasstosrt import Subtitle
+from .time import Time
+from .dialogue import Dialogue
 
-VERSION = (0, 0, 4)
+VERSION = (1, 0, 0)
 __version__ = ".".join(map(str, VERSION))
 
 __author__ = 'GitBib'
